/*
 * Copyright 2010 John Schember <john@nachtimwald.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QString>

#include "ebookread.h"
#include "epubreader.h"
#include "palmdocreader.h"
#include "pdbreader.h"
#include "ztxtreader.h"


FormatReader *EbookRead::getReader(QString filename, QString &error)
{
    FormatReader *reader = 0;

    if (filename.endsWith(".epub")) {
        reader = new EpubReader();
    }
    else if (filename.endsWith(".pdb")) {
        QString identity = PdbReader::getIdenity(filename);
        if (identity == PalmDocReader::IDENTITY) {
            reader = new PalmDocReader();
        }
        if (identity == ZTxtReader::IDENTITY) {
            reader = new ZTxtReader();
        }
        else {
            error = tr("Unsupported PDB type: %1").arg(identity);
        }
    }

    return reader;
}

QList<QString> EbookRead::supportedExtensions()
{
    QList<QString> exts;

    exts.append("pdb");
    exts.append("epub");

    return exts;
}
