/*
 * Copyright 2010 John Schember <john@nachtimwald.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "epubfileentry.h"
#include "epubfileentry_p.h"

EpubFileEntryPrivate::EpubFileEntryPrivate()
{
}

EpubFileEntryPrivate::EpubFileEntryPrivate(const EpubFileEntryPrivate &other) :
        QSharedData(other), crc32(other.crc32), compressionMethod(other.compressionMethod),
        compressedSize(other.compressedSize), uncompressedSize(other.uncompressedSize),
        dataOffset(other.dataOffset), filename(other.filename)
{
}

EpubFileEntry::EpubFileEntry()
{
    d = new EpubFileEntryPrivate;
}

EpubFileEntry::EpubFileEntry(const EpubFileEntry &other) : d(other.d)
{
}

quint32 EpubFileEntry::crc32()
{
    return d->crc32;
}

quint16 EpubFileEntry::compressionMethod()
{
    return d->compressionMethod;
}

quint32 EpubFileEntry::compressedSize()
{
    return d->compressedSize;
}

quint32 EpubFileEntry::uncompressedSize()
{
    return d->uncompressedSize;
}

quint32 EpubFileEntry::dataOffset()
{
    return d->dataOffset;
}

QString EpubFileEntry::filename()
{
    return d->filename;
}

void EpubFileEntry::setCrc32(quint32 crc)
{
    d->crc32 = crc;
}

void EpubFileEntry::setCompressionMethod(quint16 method)
{
    d->compressionMethod = method;
}

void EpubFileEntry::setCompressedSize(quint32 size)
{
    d->compressedSize = size;
}

void EpubFileEntry::setUncompressedSize(quint32 size)
{
    d->uncompressedSize = size;
}

void EpubFileEntry::setDataOffset(quint32 offset)
{
    d->dataOffset = offset;
}

void EpubFileEntry::setFilename(const QString &filename)
{
    d->filename = filename;
}
