/*
 * Copyright 2010 John Schember <john@nachtimwald.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef EPUBREADER_H
#define EPUBREADER_H

#include <QDomElement>
#include <QHash>
#include <QString>
#include <QStringList>

#include "epubfileentry.h"
#include "formatreader.h"

class EpubReader : public FormatReader
{
public:
    EpubReader();
    ~EpubReader();

    bool open(QString const &filename);
    void close();

    bool extractBook(const QString &location);
    bool extractBookRaw(const QString &location);

private:
    bool validate();
    bool drmed();
    bool readFileEntries();
    bool readOpf();
    void readNcx();
    QList<TocItem> readNcxNavPoints(const QDomElement &nodes);

    QByteArray extractFileEntry(EpubFileEntry entry);

    QHash<QString, EpubFileEntry> m_entries;
    QString m_opfDir;
    QString m_ncx;
    QHash<QString, QString> m_emanifest;
    QStringList m_espine;
    QList<TocItem> m_etoc;
};

#endif // EPUBREADER_H
