/*
 * Copyright 2010 John Schember <john@nachtimwald.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FORMATREADER_H
#define FORMATREADER_H

#include <QFile>
#include <QHash>
#include <QList>
#include <QObject>
#include <QString>
#include <QStringList>
#include <QTextCodec>

#include <tidy.h>

#include "tocitem.h"

class FormatReader : public QObject
{
public:
    FormatReader();
    ~FormatReader();

    virtual bool open(QString const &filename) = 0;
    virtual void close() = 0;

    virtual bool extractBook(const QString &location) = 0;
    virtual bool extractBookRaw(const QString &location) = 0;

    QString encoding();
    QStringList manifest();
    QStringList spine();
    QList<TocItem> toc();
    QHash<QString, QString> metadata();

    QString errorString();

    bool setEncoding(QString codec);

protected:
    QString generateXhtml(const QString &html);
    bool writeXhtml(const QString &xhtml, const QString &baseLocation, const QString &filename);

    QFile *m_file;
    QTextCodec *m_encoding;
    QStringList m_manifest;
    QStringList m_spine;
    QList<TocItem> m_toc;
    QHash<QString, QString> m_metadata;
    TidyDoc m_tidyDoc;
    QString m_errorString;

private:
    void setupTidy();
};

#endif // FORMATREADER_H
